hive-system.shell.detect

Detect available package managers and system capabilities. Delegates to babashka.fs for path resolution.

Detect available package managers and system capabilities.
Delegates to babashka.fs for path resolution.
raw docstring

detect-pkg-managersclj

(detect-pkg-managers)

Returns a map of {:manager :path} for each available package manager.

Returns a map of {:manager :path} for each available package manager.
sourceraw docstring

whichclj

(which program)

Resolve a binary name to its full path via babashka.fs/which. Returns (ok {:path ... :program ...}) or (err :shell/not-found ...).

Resolve a binary name to its full path via babashka.fs/which.
Returns (ok {:path ... :program ...}) or (err :shell/not-found ...).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries