Detect available package managers and system capabilities. Delegates to babashka.fs for path resolution.
Detect available package managers and system capabilities. Delegates to babashka.fs for path resolution.
(detect-pkg-managers)Returns a map of {:manager :path} for each available package manager.
Returns a map of {:manager :path} for each available package manager.
(which program)Resolve a binary name to its full path via babashka.fs/which. Returns (ok {:path ... :program ...}) or (err :shell/not-found ...).
Resolve a binary name to its full path via babashka.fs/which.
Returns (ok {:path ... :program ...}) or (err :shell/not-found ...).cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |